@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  gpa-option.c: 
  *
@@ -235,6 +235,8 @@ gpa_option_create_key (GPAOption *option, GPANode *parent)
 	GPANode *child;
 	GPAKey *key;
 
+	g_return_val_if_fail (option != NULL, NULL);
+
 	key_node = gpa_node_new (GPA_TYPE_KEY, GPA_NODE_ID (option));
 	key = (GPAKey *) key_node;
 	key->option = gpa_node_ref (GPA_NODE (option));
@@ -243,6 +245,7 @@ gpa_option_create_key (GPAOption *option, GPANode *parent)
 
 	if (option->type == GPA_OPTION_TYPE_LIST) {
 		child = gpa_option_get_child_by_id (option, option->value);
+		if (child != NULL)
 		child = child->children;
 	} else {
 		child = GPA_NODE (option)->children;
@@ -383,11 +386,12 @@ gpa_option_new_from_tree (xmlNodePtr tree, GPANode *parent)
 new_from_tree_option_loaded:
 	locked = xmlGetProp (tree, "Locked");
 	
-	if (locked && !strcmp (locked, "true")) {
-		GPA_NODE_SET_FLAGS (option, NODE_FLAG_LOCKED);
-	} else {
-		GPA_NODE_UNSET_FLAGS (option, NODE_FLAG_LOCKED);
-	}		
+	if (option)
+		if (locked && !strcmp (locked, "true")) {
+			GPA_NODE_SET_FLAGS (option, NODE_FLAG_LOCKED);
+		} else {
+			GPA_NODE_UNSET_FLAGS (option, NODE_FLAG_LOCKED);
+		}		
 	
 new_from_tree_done:
 	my_xmlFree (locked);
